/////////////////////////////////////////////////////////////////////////////
///
/// @file config.h
///
/// Configuration settings.
/// This is a configuration file for the program "cmgraphs.cpp".
/// It defines the map which is analyzed, the ranges of parameters,
/// and the phase space information.
///
/// @namespace custom
///
/// Customizable settings that are supposed to be modified and/or chosen
/// by the user of the software. This namespace contains various constants,
/// classes and functions which can be modified in order to customize
/// the programs for the computation of Conley-Morse graphs
/// and the continuation diagrams.
///
/// @author Pawel Pilarczyk
///
/////////////////////////////////////////////////////////////////////////////

// Copyright (C) 1997-2008 by Pawel Pilarczyk.
//
// This file is part of my research software package.  This is free software;
// you can redistribute it and/or modify it under the terms of the GNU
// General Public License as published by the Free Software Foundation;
// either version 2 of the License, or (at your option) any later version.
//
// This software is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License along
// with this software; see the file "license.txt".  If not, write to the
// Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
// MA 02111-1307, USA.

// Started on February 9, 2008. Last revision: February 9, 2008.


#ifndef _CMGRAPHS_CONFIG_H_
#define _CMGRAPHS_CONFIG_H_


// --------------------------------------------------
// --------------- THE MAP SELECTION ----------------
// --------------------------------------------------

#include "popmodel.h"

/// Defines the type of the map to be used for the computations.
/// The corresponding header file must be included prior to this definition.
typedef MapPopModel theMapType;


// --------------------------------------------------
// -------------- THE PARAMETER RANGES --------------
// --------- AND THE PHASE SPACE SELECTION ----------
// --------------------------------------------------

#include "parpop0p.h"
#include "parpop2p.h"
#include "parpop2s.h"
#include "parpop3p.h"
using namespace custom::pop2p;


// --------------------------------------------------
// ------------------ LIMITATIONS -------------------
// --------------------------------------------------

#include "limits2d.h"
using namespace custom::limits2d;


// --------------------------------------------------
// --------------- KNOWN CONLEY INDEX ---------------
// --------------------------------------------------

#include "indknown.h"
#include "indpop2d.h"
//using namespace custom::noKnownIndices;
using namespace custom::popOriginInd2d;


// --------------------------------------------------
// ------------- COMPATIBILITY CONTROL --------------
// --------------------------------------------------

/// The control number that is used to confirm the compatibility
/// between the coordinator and workers.
/// Please, increase this number by 1 every time the configuration
/// of the program changes substantially (e.g., different parameter ranges,
/// different numbers of subintervals, or different maps are chosen).
const int controlNumber = 31131;


#endif // _CMGRAPHS_CONFIG_H_

